part of 'exercise_plan_custom_add_bloc.dart';

@immutable
abstract class ExercisePlanCustomAddState extends Equatable {
  const ExercisePlanCustomAddState();

  @override
  List<Object> get props => [];
}

class ExercisePlanCustomAddInitial extends ExercisePlanCustomAddState {
  const ExercisePlanCustomAddInitial();
}

class ExercisePlanCustomAddLoading extends ExercisePlanCustomAddState {
  const ExercisePlanCustomAddLoading();
}

class ExercisePlanCustomAddReady extends ExercisePlanCustomAddState {
  const ExercisePlanCustomAddReady();
}

class ExercisePlanCustomAddError extends ExercisePlanCustomAddState {
  final String message;
  const ExercisePlanCustomAddError({required this.message});

  @override
  List<Object> get props => [message];
}
